@@ -41,7 +41,7 @@ extern "C" {
 #include <libotr/userstate.h>
 }
 
-class OtrlChatInterface: public TQObject
+class KDE_EXPORT OtrlChatInterface: public TQObject
 {
 	Q_OBJECT
 
@@ -82,7 +82,7 @@ private:
 	TQTimer m_forwardSecrecyTimer;
 };
 
- class KeyGenThread : public TQThread {
+class KeyGenThread : public TQThread {
 
 private:
 	TQString accountname;
